==> foundation-2.6.1.tgz: package/SocialAmazon/SocialAmazon.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const SocialAmazon = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M52.02 35.981c-4.333.371-8.663.795-12.852 2.047-8.593 2.574-12.979 8.387-12.838 16.969.128 7.734 4.601 12.865 12.285 13.684 4.953.527 9.708-.293 13.728-3.584 1.151-.941 2.23-1.971 3.249-2.875 1.665 1.838 3.229 3.666 4.906 5.387 1.063 1.09 2.088 1.047 3.231.068 2.144-1.832 4.275-3.68 6.407-5.527 1.152-1 1.302-1.889.268-3.059-2.529-2.867-3.404-6.16-3.337-9.955a399.95 399.95 0 00-.161-20.285c-.171-5.197-2.768-9.066-7.554-11.184-7.35-3.25-14.798-3.178-22.127.051-4.949 2.184-7.977 6.076-9.16 11.377-.388 1.742.076 2.392 1.83 2.602 2.529.303 5.055.627 7.581.957 1.393.182 2.168-.236 2.47-1.631.899-4.154 5.005-6.209 8.898-5.631 2.513.373 4.387 1.963 4.771 4.371.312 1.959.289 3.973.413 5.941-.331.09-.456.145-.586.156-.474.047-.948.08-1.422.121zm-.185 19.772c-1.262 1.906-2.879 3.281-5.155 3.664-3.688.619-6.401-1.754-6.672-5.738-.355-5.217 2.309-8.791 7.459-9.781 2.077-.4 4.213-.496 6.422-.742.021 4.505.473 8.777-2.054 12.597z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M75.38 70.892c-.357.106-.698.262-1.042.408-4.914 2.096-9.966 3.748-15.213 4.783-4.954.979-9.942 1.473-14.99 1.006-6.205-.57-11.993-2.566-17.527-5.324-3.522-1.754-6.962-3.672-10.447-5.502-1.093-.574-2.095-.404-2.656.391-.554.783-.362 1.814.616 2.584 3.468 2.729 6.845 5.594 10.478 8.086 6.773 4.645 14.24 7.418 23.981 7.414 7.914-.199 16.618-2.611 24.675-7.299 1.434-.834 2.808-1.785 4.148-2.766 1.021-.748 1.24-1.848.718-2.789-.504-.91-1.62-1.324-2.741-.992z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M82.865 63.228c-3.83-.387-7.529.078-10.761 2.443-.751.547-1.186 1.287-.776 2.203.391.873 1.19.986 2.077.861 1.678-.236 3.363-.428 5.046-.639l.012.131c.612 0 1.223-.008 1.833.002.707.012 1.084.32.921 1.08-.179.828-.3 1.674-.55 2.479-.481 1.555-1.103 3.068-1.519 4.637-.131.494.031 1.324.381 1.621.399.336 1.175.383 1.754.305.408-.053.806-.477 1.13-.811 2.582-2.672 3.898-5.943 4.29-9.576.385-3.57-.248-4.373-3.838-4.736z"
  }));
});
SocialAmazon.displayName = 'SocialAmazon';
export const SocialAmazonDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/SocialAmazon/SocialAmazon.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var SocialAmazon = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M52.02 35.981c-4.333.371-8.663.795-12.852 2.047-8.593 2.574-12.979 8.387-12.838 16.969.128 7.734 4.601 12.865 12.285 13.684 4.953.527 9.708-.293 13.728-3.584 1.151-.941 2.23-1.971 3.249-2.875 1.665 1.838 3.229 3.666 4.906 5.387 1.063 1.09 2.088 1.047 3.231.068 2.144-1.832 4.275-3.68 6.407-5.527 1.152-1 1.302-1.889.268-3.059-2.529-2.867-3.404-6.16-3.337-9.955a399.95 399.95 0 00-.161-20.285c-.171-5.197-2.768-9.066-7.554-11.184-7.35-3.25-14.798-3.178-22.127.051-4.949 2.184-7.977 6.076-9.16 11.377-.388 1.742.076 2.392 1.83 2.602 2.529.303 5.055.627 7.581.957 1.393.182 2.168-.236 2.47-1.631.899-4.154 5.005-6.209 8.898-5.631 2.513.373 4.387 1.963 4.771 4.371.312 1.959.289 3.973.413 5.941-.331.09-.456.145-.586.156-.474.047-.948.08-1.422.121zm-.185 19.772c-1.262 1.906-2.879 3.281-5.155 3.664-3.688.619-6.401-1.754-6.672-5.738-.355-5.217 2.309-8.791 7.459-9.781 2.077-.4 4.213-.496 6.422-.742.021 4.505.473 8.777-2.054 12.597z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M75.38 70.892c-.357.106-.698.262-1.042.408-4.914 2.096-9.966 3.748-15.213 4.783-4.954.979-9.942 1.473-14.99 1.006-6.205-.57-11.993-2.566-17.527-5.324-3.522-1.754-6.962-3.672-10.447-5.502-1.093-.574-2.095-.404-2.656.391-.554.783-.362 1.814.616 2.584 3.468 2.729 6.845 5.594 10.478 8.086 6.773 4.645 14.24 7.418 23.981 7.414 7.914-.199 16.618-2.611 24.675-7.299 1.434-.834 2.808-1.785 4.148-2.766 1.021-.748 1.24-1.848.718-2.789-.504-.91-1.62-1.324-2.741-.992z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M82.865 63.228c-3.83-.387-7.529.078-10.761 2.443-.751.547-1.186 1.287-.776 2.203.391.873 1.19.986 2.077.861 1.678-.236 3.363-.428 5.046-.639l.012.131c.612 0 1.223-.008 1.833.002.707.012 1.084.32.921 1.08-.179.828-.3 1.674-.55 2.479-.481 1.555-1.103 3.068-1.519 4.637-.131.494.031 1.324.381 1.621.399.336 1.175.383 1.754.305.408-.053.806-.477 1.13-.811 2.582-2.672 3.898-5.943 4.29-9.576.385-3.57-.248-4.373-3.838-4.736z"
  }));
});
SocialAmazon.displayName = 'SocialAmazon';
export var SocialAmazonDimensions = {
  height: 100,
  width: 100
};
